from mydots import cli


if __name__ == "__main__":
    cli.main()
